from buz.event.kombu.consume_strategy.consume_strategy import ConsumeStrategy
from buz.event.kombu.consume_strategy.queue_per_subscriber_consume_strategy import QueuePerSubscriberConsumeStrategy

__all__ = ["ConsumeStrategy", "QueuePerSubscriberConsumeStrategy"]



from buz.event.kombu.retry.max_retries_negative_exception import InvalidMaxRetriesParamException
from buz.event.kombu.retry.publish_retry_policy import PublishRetryPolicy
from buz.event.kombu.retry.simple_publish_retry_policy import SimplePublishRetryPolicy
from buz.event.kombu.retry.consumed_event_retry import ConsumedEventRetry
from buz.event.kombu.retry.consumed_event_retry_repository import ConsumedEventRetryRepository
from buz.event.kombu.retry.consume_retrier import ConsumeRetrier
from buz.event.kombu.retry.max_retries_consume_retrier import MaxRetriesConsumeRetrier
from buz.event.kombu.retry.reject_callback import RejectCallback

__all__ = [
    "PublishRetryPolicy",
    "SimplePublishRetryPolicy",
    "ConsumedEventRetry",
    "ConsumedEventRetryRepository",
    "ConsumeRetrier",
    "MaxRetriesConsumeRetrier",
    "RejectCallback",
    "InvalidMaxRetriesParamException",
]



from buz.event.kombu.serializer_enum import SerializerEnum
from buz.event.kombu.event_not_published_exception import EventNotPublishedException
from buz.event.kombu.subscribers_not_found_exception import SubscribersNotFoundException
from buz.event.kombu.event_restore_exception import EventRestoreException
from buz.event.kombu.kombu_event_bus import KombuEventBus
from buz.event.kombu.kombu_consumer import KombuConsumer
from buz.event.kombu.worker import Worker

__all__ = [
    "SerializerEnum",
    "EventNotPublishedException",
    "KombuEventBus",
    "KombuConsumer",
    "Worker",
    "EventRestoreException",
    "SubscribersNotFoundException",
]



from buz.event.kombu.execution_strategy.execution_strategy import ExecutionStrategy
from buz.event.kombu.execution_strategy.self_process_execution_strategy import SelfProcessExecutionStrategy


__all__ = ["SelfProcessExecutionStrategy", "ExecutionStrategy"]



from buz.event.kombu import KombuConsumer
from buz.event.kombu.execution_strategy.execution_strategy import ExecutionStrategy


class SelfProcessExecutionStrategy(ExecutionStrategy):
    def __init__(self, kombu_consumer: KombuConsumer):
        self.__kombu_consumer = kombu_consumer

    def start(self) -> None:
        self.__kombu_consumer.run()

    def stop(self) -> None:
        self.__kombu_consumer.should_stop = True
